@@ -11,7 +11,6 @@
 #include <KCrash>
 #include <KDBusService>
 #include <KLocalizedString>
-#include <KXMessages>
 // PolkitQt1
 #include <PolkitQt1/Subject>
 // Qt
@@ -36,18 +35,15 @@ int main(int argc, char *argv[])
 #if HAVE_PROC_TRACE_CTL
     int mode = PROC_TRACE_CTL_DISABLE;
     procctl(P_PID, getpid(), PROC_TRACE_CTL, &mode);
-#endif
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
 #endif
     KCrash::setFlags(KCrash::AutoRestart);
 
     QApplication app(argc, argv);
     app.setQuitOnLastWindowClosed(false);
 
-    KLocalizedString::setApplicationDomain("polkit-kde-authentication-agent-1");
+    KLocalizedString::setApplicationDomain(QByteArrayLiteral("polkit-kde-authentication-agent-1"));
 
-    KAboutData aboutData("polkit-kde-authentication-agent-1", i18n("PolicyKit1 KDE Agent"), POLKIT_KDE_1_VERSION);
+    KAboutData aboutData("polkit-kde-authentication-agent-1", QString(), POLKIT_KDE_1_VERSION);
     aboutData.addLicense(KAboutLicense::GPL);
     aboutData.addCredit(i18n("(c) 2009 Red Hat, Inc."));
     aboutData.addAuthor(i18n("Lukáš Tinkl"), i18n("Maintainer"), "ltinkl@redhat.com");
@@ -57,7 +53,7 @@ int main(int argc, char *argv[])
     KAboutData::setApplicationData(aboutData);
 
     // ensure singleton run
-    KDBusService service(KDBusService::Unique);
+    KDBusService service(KDBusService::Unique | KDBusService::Replace);
 
     // disable session management
     auto disableSessionManagement = [](QSessionManager &sm) {
@@ -67,16 +63,6 @@ int main(int argc, char *argv[])
     QObject::connect(&app, &QGuiApplication::commitDataRequest, disableSessionManagement);
     QObject::connect(&app, &QGuiApplication::saveStateRequest, disableSessionManagement);
 
-    // Force extreme focus protection to prevent losing focus to any other window.
-    // https://bugs.kde.org/show_bug.cgi?id=312325
-    KXMessages msg;
-    const QString message = QStringLiteral(
-        "fpplevel=4\n"
-        "fpplevelrule=2\n"
-        "wmclass=polkit-kde-authentication-agent-1\n"
-        "wmclassmatch=1\n");
-    msg.broadcastMessage("_KDE_NET_WM_TEMPORARY_RULES", message, -1);
-
     // register agent
     PolicyKitListener *listener = new PolicyKitListener(&app);
 
